<?php

namespace Drupal\comingsoon_mode\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RedirectDestinationInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Url;


/**
 * Subscribe to KernelEvents::RESPONSE events.
 */
class RedirectComingSoonSubscriber implements EventSubscriberInterface
{

  /**
   * Request stack.
   * 
   *  @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;
  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The destination helper.
   *
   * @var \Drupal\Core\Routing\RedirectDestinationInterface
   */
  protected $destinationHelper;


  /**
   * Constructs a RedirectComingSoonSubscriber object.
   * 
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The account service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\Routing\RedirectDestinationInterface $destination_helper
   *   The destination helper.
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path for the current request.
   */

  public function __construct(
    RequestStack                 $requestStack,
    AccountInterface             $account,
    ConfigFactoryInterface       $config_factory,
    RedirectDestinationInterface $destination_helper
  ) {
    $this->requestStack = $requestStack;
    $this->account = $account;
    $this->configFactory = $config_factory;
    $this->destinationHelper = $destination_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents()
  {
    // Set priority to be -1 to fire after the destination parameter
    // is processed, so we can ignore if the destination is set to the same page
    // we're accessing.
    return [
      KernelEvents::RESPONSE => ['redirectToComingSoonEvent', -1],
    ];
  }

  /**
   * This method is called whenever the KernelEvents::RESPONSE event is
   * dispatched.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The Response event object.
   */
  public function redirectToComingSoonEvent(ResponseEvent $event)
  {
    $request = $this->requestStack->getCurrentRequest();
    $cuurentRoute = $request->attributes->get('_route');
    $isAnonymous = $this->account->isAnonymous();
    $config = $this->configFactory->get('comingsoon_mode.settings');
    $comingSoonCkeck = $config->get('comingsoon_ckeck') ? $config->get('comingsoon_ckeck') : 0;

    if ($comingSoonCkeck == 1) {
      if ($isAnonymous && $cuurentRoute != 'user.login') {
        $url = Url::fromRoute('comingsoon.page');
        $response = new RedirectResponse($url->toString());
        $response->send();
        return;
      }
    }


    return;
  }
}
